@@ -212,7 +212,7 @@ fn flatpak(target_dir: PathBuf, arguments: Flatpak) {
         c.arg(format!("{}/{}", flatpak_build_rel, "host"));
     }
     c.arg(gra_gen.join("data").join(format!(
-        "{}.yml",
+        "{}.dev.yml",
         project_descriptor.app.as_ref().unwrap().id
     )));
     let mut c = c.spawn().unwrap();
